// Copyright © 2022 Cisco Systems, Inc. and its affiliates.
// All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package utils

import (
	"strings"

	log "github.com/sirupsen/logrus"

	"github.com/openclarity/kubeclarity/api/client/models"
	"github.com/openclarity/kubeclarity/shared/pkg/utils/vulnerability"
)

func GetVulnerabilitySeverityFromString(severity string) models.VulnerabilitySeverity {
	switch strings.ToUpper(severity) {
	case vulnerability.DEFCON1, vulnerability.CRITICAL:
		return models.VulnerabilitySeverityCRITICAL
	case vulnerability.HIGH:
		return models.VulnerabilitySeverityHIGH
	case vulnerability.MEDIUM:
		return models.VulnerabilitySeverityMEDIUM
	case vulnerability.LOW:
		return models.VulnerabilitySeverityLOW
	case vulnerability.NEGLIGIBLE:
		return models.VulnerabilitySeverityNEGLIGIBLE
	default:
		log.Warnf("Unknown severity: %v", severity)
		return models.VulnerabilitySeverityNEGLIGIBLE
	}
}
